@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda;
-$Qgoda::VERSION = 'v0.9.3';
+$Qgoda::VERSION = '0.9.4';
 use strict;
 
 # FIXME! This assumes that we are a top-level package. Instead,
@@ -30,7 +30,7 @@ use vars qw(@EXPORT $VERSION);
 @EXPORT = qw($VERSION);
 $VERSION = '0.9.3';
 
-use Locale::TextDomain qw(qgoda);
+use Locale::TextDomain 1.30 qw(qgoda);
 use Locale::Messages;
 use Locale::gettext_dumb;
 use File::Find;
@@ -44,7 +44,7 @@ use Symbol qw(gensym);
 use IPC::Open3 qw(open3);
 use IPC::Signal;
 use POSIX qw(:sys_wait_h);
-use Template::Plugin::Gettext 0.6;
+use Template::Plugin::Gettext 0.7;
 use List::Util 1.45 qw(uniq);
 use YAML::XS 0.67;
 use boolean;
