@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda::Builder;
-$Qgoda::Builder::VERSION = 'v0.9.3';
+$Qgoda::Builder::VERSION = '0.9.4';
 use strict;
 
 use Locale::TextDomain qw('qgoda');
@@ -186,7 +186,6 @@ sub processAsset {
 
     my $content = $self->readAssetContent($asset, $site);
     $asset->{content} = $content;
-    Encode::_utf8_on($asset->{content}) if !$asset->{raw};
     my @processors = $qgoda->getProcessors($asset);
     foreach my $processor (@processors) {
         my $short_name = ref $processor;
