@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda::Config;
-$Qgoda::Config::VERSION = 'v0.9.3';
+$Qgoda::Config::VERSION = '0.9.4';
 use strict;
 
 use Locale::TextDomain qw('qgoda');
@@ -41,7 +41,6 @@ sub new {
     my $q = Qgoda->new;
     my $logger = $q->logger('config');
 
-	$logger->info(__"Reading configuration");
     my $filename;
     if (!empty $args{filename}) {
         $filename = $args{filename};
