@@ -17,13 +17,14 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda::Locale::XGettext;
-$Qgoda::Locale::XGettext::VERSION = 'v0.9.3';
+$Qgoda::Locale::XGettext::VERSION = '0.9.4';
 use strict;
 
 use Locale::TextDomain qw(qgoda);
 use Cwd qw(getcwd realpath);
 use Scalar::Util qw(reftype);
 use File::Spec;
+use Locale::XGettext 0.7;
 
 use Qgoda;
 use Qgoda::Util qw(read_file flatten2hash);
@@ -31,7 +32,6 @@ use Qgoda::Util::Translate qw(get_masters);
 use Qgoda::CLI;
 use Qgoda::Splitter;
 
-use Locale::XGettext '0.4';
 use base qw(Locale::XGettext);
 
 sub readFile {
