@@ -17,7 +17,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Qgoda::Util;
-$Qgoda::Util::VERSION = 'v0.9.3';
+$Qgoda::Util::VERSION = '0.9.4';
 use strict;
 
 use IO::File;
@@ -100,7 +100,7 @@ sub read_body($$) {
     my ($filename, $placeholder) = @_;
 
     my $fh = IO::File->new;
-    open $fh, "<", $filename or return;
+    open $fh, "<:encoding(UTF-8)", $filename or return;
 
     undef $!;
     my $first_line = <$fh>;
